/*
 * Example 41-10
 * A SIGINT handler.
 */

#include <signal.h>
/*
* Token and handler procedure for async event.
*/
static Tcl_AsyncHandler sig_Token;
int Sig_HandleSafe(ClientData data,
	Tcl_Interp *interp, int code);
/*
* Set up a signal handler for interrupts.
* This also registers a handler for a Tcl asynchronous
* event, which is enabled in the interrupt handler.
*/
void
Sig_Setup(interp)
	Tcl_Interp *interp;
{
	RETSIGTYPE (*oldhandler)();
	oldhandler = signal(SIGINT, Sig_HandleINT);
	if ((int)oldhandler == -1) {
		perror("signal failed");
		exit(1);
	}
	sig_Token = Tcl_AsyncCreate(Sig_HandleSafe, NULL);
#ifdef HAVE_SIGINTERRUPT
	/*
	 * Ensure that wait() kicks out on interrupt.
	 */
	siginterrupt(SIGINT, 1);
#endif
}
/*
 * Invoked upon interrupt (control-C)
 */
RETSIGTYPE
Sig_HandleINT(sig)
	int sig;
{
	Tcl_AsyncMark(sig_Token);
}
/*
* Invoked at a safe point sometime after Tcl_AsyncMark
*/
int
Sig_HandleSafe(data, interp, code)
	ClientData data;
	Tcl_Interp *interp;
	int code;
{
	if (interp == NULL) {
	    /*
	     * Called from the Tk idle loop.
	     */
	    interp = myInterp;
	}
	Dbg_On(interp, 1);						/* Enter the Tcl debugger */
}


