/*
 * Example 41-12
 * A configure.in for your package.
 */

# Name a file autoconf should find in the source directory
AC_INIT(randomPkg.c)

# See if there was a command-line option for where Tcl is; if
# not, assume that its top-level directory is a sibling of ours.
AC_ARG_WITH(tcl, 
	[  --with-tcl=DIR 							use Tcl 8.0 binaries from DIR],
	TCL_BIN_DIR=$withval, TCL_BIN_DIR=`cd ../tcl8.0/unix; pwd`)
if test ! -d $TCL_BIN_DIR; then
    AC_MSG_ERROR(Tcl directory $TCL_BIN_DIR doesn't exist)
fi
AC_ARG_WITH(tk, 
	[  --with-tk=DIR 							use Tk 8.0 binaries from DIR],
	TK_BIN_DIR=$withval, TK_BIN_DIR=`cd ../tk8.0/unix; pwd`)
if test ! -d $TK_BIN_DIR; then
    AC_MSG_ERROR(Tk directory $TK_BIN_DIR doesn't exist)
fi

# Determine signal handler return type
AC_TYPE_SIGNAL()
AC_CHECK_FUNC(siginterrupt, AC_DEFINE(HAVE_SIGINTERRUPT) ,)

# Use the information from the Tcl and Tk configuration

. $TCL_BIN_DIR/tclConfig.sh
. $TK_BIN_DIR/tkConfig.sh

CC=$TCL_CC
AC_SUBST(CC)

# Expand @references@ to autoconf variables in Makefile.in

AC_SUBST(TCL_SHLIB_CFLAGS)
AC_SUBST(TCL_SHLIB_LD)
AC_SUBST(TCL_SHLIB_LD_LIBS)
AC_SUBST(TCL_SHLIB_SUFFIX)

AC_SUBST(TCL_LIB_SPEC)
AC_SUBST(TCL_DEFS)
AC_SUBST(TCL_LIBS)
AC_SUBST(TCL_PREFIX)

AC_SUBST(TK_LIB_SPEC)
AC_SUBST(TK_LIBS)
AC_SUBST(TK_DEFS)

# Extracted from the dbg configure.in
DBG_MAJOR_VERSION=5
DBG_MINOR_VERSION=21
DBG_MICRO_VERSION=0
DBG_VERSION=$DBG_MAJOR_VERSION.$DBG_MINOR_VERSION
DBG_VERSION_FULL=$DBG_VERSION.$DBG_MICRO_VERSION
DBG_INCLUDE_DIR=$TCL_SRC_DIR/generic

AC_SUBST(DBG_MAJOR_VERSION)
AC_SUBST(DBG_MINOR_VERSION)
AC_SUBST(DBG_MICRO_VERSION)
AC_SUBST(DBG_VERSION_FULL)
AC_SUBST(DBG_VERSION)
AC_SUBST(DBG_INCLUDE_DIR)

AC_OUTPUT(Makefile)


