/*
 * Example 42-1
 * Using the Hash package.
 */

static Tcl_HashTable mxInstanceCmdTable;

typedef struct {
	char *name;					/* Operation name. */
	int (*proc)();					/* Procedure to process operation. */
} CmdInfo;

static CmdInfo commands[] = {
	{"caret",				Mx_CaretCmd},
	{"clean",				Mx_CleanCmd},
	{"column",				Mx_ColumnCmd},
	{"configure",				Mx_ConfigureCmd},
	/* Lines ommitted */
	{"write",				Mx_WriteCmd},
	{"written",				Mx_WrittenCmd},
	{(char *) NULL, (int (*)()) NULL}
};
/*
* MxCmdInit creates a hash table of widget commands.
* The hash table maps from argv[1] to C-procedures.
*/
void
MxCmdInit(mxwPtr)
 MxWidget *mxwPtr;
{
	CmdInfo *cmd;

	Tcl_InitHashTable(&mxInstanceCmdTable,
		TCL_STRING_KEYS);
	for (cmd = commands; cmd->name != NULL ; cmd++) {
		int newEntry;
		Tcl_HashEntry *entryPtr;
		entryPtr = 
			Tcl_CreateHashEntry(&mxInstanceCmdTable,
			cmd->name, &newEntry);
		Tcl_SetHashValue(entryPtr, cmd->proc);
	}
	return;
}
/*
* MxCmdFind uses the hash table to find the procedure
* associated with an operation name.
*/
int (*
MxCmdFind(string))()
	char *string;
{
	Tcl_HashEntry *entryPtr;
	int (*handler)();
	entryPtr = Tcl_FindHashEntry(&mxInstanceCmdTable,
		string);
	if (entryPtr == NULL) {
		return NULL;
	}
	handler = (int(*)())Tcl_GetHashValue(entryPtr);
	return handler;
}


